==> eiffelstudio-18.07.10.1981.tar: F_code/C2/in68.c <==
/*
 * Code for class INI_DOCUMENT_READER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in68.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INI_DOCUMENT_READER}.make */
void F84_1184 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 83, Current, 0, 0, 1358);
	RTHOOK(1);
	F84_1190(Current);
	RTHOOK(2);
	RTEE;
}

/* {INI_DOCUMENT_READER}.read_document */
EIF_REFERENCE F84_1185 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {INI_DOCUMENT_READER}.errors */
EIF_REFERENCE F84_1186 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {INI_DOCUMENT_READER}.read_from_file */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F84_1188 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_INTEGER_32  EIF_VOLATILE ti4_1;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	RTLD;
	RTXD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLR(5,saved_except);
	RTLIU(6);
	RTXSLS;
	
	RTEAA("read_from_file", 83, Current, 3, 2, 1362);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc3) {
		RTHOOK(2);
		F84_1190(Current);
		RTHOOK(3);
		tr1 = RTLNS(eif_new_type(1050, 0x00).id, 1050, _OBJSIZ_1_1_0_3_0_0_0_0_);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3400[Dtype(arg1)-667])(RTCW(arg1));
		F1049_7966(RTCW(tr1), ti4_1);
		loc1 = (EIF_REFERENCE) tr1;
		for (;;) {
			RTHOOK(4);
			tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5081[Dtype(arg1)-667])(RTCW(arg1));
			if (tb1) break;
			RTHOOK(5);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R5032[Dtype(arg1)-667])(RTCW(arg1));
			RTHOOK(6);
			loc2 = *(EIF_REFERENCE *)(RTCW(arg1) + O4963[Dtype(arg1)-665]);
			RTHOOK(7);
			if ((EIF_BOOLEAN)(loc2 != NULL)) {
				RTHOOK(8);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R6829[Dtype(loc1)-1050])(RTCW(loc1), loc2);
			}
			RTHOOK(9);
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5081[Dtype(arg1)-667])(RTCW(arg1));
			if ((EIF_BOOLEAN) !tb2) {
				RTHOOK(10);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R6833[Dtype(loc1)-1050])(RTCW(loc1), (EIF_CHARACTER_8) '\012');
			}
		}
		RTHOOK(11);
		F84_1189(Current, loc1, arg2);
	}
	RTE_E
	RTXSC;
	RTHOOK(12);
	loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(13);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(14);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {INI_DOCUMENT_READER}.read_from_buffer */
void F84_1189 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTEAA("read_from_buffer", 83, Current, 2, 2, 1363);
	RTGC;
	RTHOOK(1);
	F84_1190(Current);
	RTHOOK(2);
	loc1 = F84_1192(Current, arg2);
	RTHOOK(3);
	F84_1191(Current, loc1, arg1, arg2);
	RTHOOK(4);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		RTHOOK(5);
		loc2 = F84_1193(Current);
		RTHOOK(6);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
		F224_2843(RTCW(tr1), loc2);
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {INI_DOCUMENT_READER}.reset */
void F84_1190 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("reset", 83, Current, 0, 0, 1364);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {920,273,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 920, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F921_7031(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	RTHOOK(3);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {INI_DOCUMENT_READER}.parse_buffer */
void F84_1191 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_BOOLEAN arg3)
{
	GTCX
	RTEX;
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("parse_buffer", 83, Current, 1, 3, 1365);
	RTGC;
	RTHOOK(1);
	F55_525(RTCW(arg1), arg2);
	RTHOOK(2);
	loc1 = F55_521(RTCW(arg1));
	RTHOOK(3);
	if ((EIF_BOOLEAN) !loc1) {
		RTHOOK(4);
		tr1 = F55_520(RTCW(arg1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		loc1 = (EIF_BOOLEAN) arg3;
	}
	RTHOOK(6);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) loc1;
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {INI_DOCUMENT_READER}.create_ini_parser */
EIF_REFERENCE F84_1192 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("create_ini_parser", 83, Current, 0, 1, 1366);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(54, 0x00).id, 54, _OBJSIZ_3_1_0_1_0_0_0_0_);
	F55_518(RTCW(tr1), ((EIF_INTEGER_32) 2147483647L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F55_527(RTCW(Result), arg1);
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {INI_DOCUMENT_READER}.create_document_visitor */
EIF_REFERENCE F84_1193 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("create_document_visitor", 83, Current, 0, 0, 1367);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(164, 0x00).id, 164, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F165_2137(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit68 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C2/in68.c <==
/*
 * Code for class INI_DOCUMENT_READER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in68.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INI_DOCUMENT_READER}.make */
void F84_1195 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 83, Current, 0, 0, 1368);
	RTHOOK(1);
	F84_1201(Current);
	RTHOOK(2);
	RTEE;
}

/* {INI_DOCUMENT_READER}.read_document */
EIF_REFERENCE F84_1196 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {INI_DOCUMENT_READER}.errors */
EIF_REFERENCE F84_1197 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {INI_DOCUMENT_READER}.read_from_file */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F84_1199 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	RTED;
	EIF_REFERENCE EIF_VOLATILE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE EIF_VOLATILE loc2 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_INTEGER_32  EIF_VOLATILE ti4_1;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	EIF_BOOLEAN  EIF_VOLATILE tb2;
	RTLD;
	RTXD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLR(5,saved_except);
	RTLIU(6);
	RTXSLS;
	
	RTEAA("read_from_file", 83, Current, 3, 2, 1372);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc3) {
		RTHOOK(2);
		F84_1201(Current);
		RTHOOK(3);
		tr1 = RTLNS(eif_new_type(1055, 0x01).id, 1055, _OBJSIZ_1_1_0_3_0_0_0_0_);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5398[Dtype(arg1)-772])(RTCW(arg1));
		F1054_8039(RTCW(tr1), ti4_1);
		loc1 = (EIF_REFERENCE) tr1;
		for (;;) {
			RTHOOK(4);
			tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5443[Dtype(arg1)-799])(RTCW(arg1));
			if (tb1) break;
			RTHOOK(5);
			(FUNCTION_CAST(void, (EIF_REFERENCE)) R4917[Dtype(arg1)-799])(RTCW(arg1));
			RTHOOK(6);
			loc2 = *(EIF_REFERENCE *)(RTCW(arg1) + O4848[Dtype(arg1)-443]);
			RTHOOK(7);
			if ((EIF_BOOLEAN)(loc2 != NULL)) {
				RTHOOK(8);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R6882[Dtype(loc1)-1055])(RTCW(loc1), loc2);
			}
			RTHOOK(9);
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5443[Dtype(arg1)-799])(RTCW(arg1));
			if ((EIF_BOOLEAN) !tb2) {
				RTHOOK(10);
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_CHARACTER_8)) R6886[Dtype(loc1)-1055])(RTCW(loc1), (EIF_CHARACTER_8) '\012');
			}
		}
		RTHOOK(11);
		F84_1200(Current, loc1, arg2);
	}
	RTE_E
	RTXSC;
	RTHOOK(13);
	loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(14);
	RTER;
	/* NOTREACHED */
	RTE_EE
	RTHOOK(15);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {INI_DOCUMENT_READER}.read_from_buffer */
void F84_1200 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTEAA("read_from_buffer", 83, Current, 2, 2, 1373);
	RTGC;
	RTHOOK(1);
	F84_1201(Current);
	RTHOOK(2);
	loc1 = F84_1203(Current, arg2);
	RTHOOK(3);
	F84_1202(Current, loc1, arg1, arg2);
	RTHOOK(4);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
		RTHOOK(5);
		loc2 = F84_1204(Current);
		RTHOOK(6);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
		F223_2822(RTCW(tr1), loc2);
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {INI_DOCUMENT_READER}.reset */
void F84_1201 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("reset", 83, Current, 0, 0, 1374);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,919,0xFF01,248,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 919, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F920_6832(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	RTHOOK(3);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {INI_DOCUMENT_READER}.parse_buffer */
void F84_1202 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_BOOLEAN arg3)
{
	GTCX
	RTEX;
	EIF_BOOLEAN loc1 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("parse_buffer", 83, Current, 1, 3, 1375);
	RTGC;
	RTHOOK(1);
	F56_527(RTCW(arg1), arg2);
	RTHOOK(2);
	loc1 = F56_523(RTCW(arg1));
	RTHOOK(3);
	if ((EIF_BOOLEAN) !loc1) {
		RTHOOK(4);
		tr1 = F56_522(RTCW(arg1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
		RTHOOK(5);
		loc1 = (EIF_BOOLEAN) arg3;
	}
	RTHOOK(6);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) loc1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {INI_DOCUMENT_READER}.create_ini_parser */
EIF_REFERENCE F84_1203 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("create_ini_parser", 83, Current, 0, 1, 1376);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(55, 0x01).id, 55, _OBJSIZ_3_1_0_1_0_0_0_0_);
	F56_520(RTCW(tr1), ((EIF_INTEGER_32) 2147483647L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	F56_529(RTCW(Result), arg1);
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {INI_DOCUMENT_READER}.create_document_visitor */
EIF_REFERENCE F84_1204 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("create_document_visitor", 83, Current, 0, 0, 1377);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(161, 0x01).id, 161, _OBJSIZ_2_0_0_0_0_0_0_0_);
	F162_2102(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit68 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
